package gpsys.cos;

import java.util.Random;
import gpsys.*;
import gpsys.primitives.*;

/**
 * The Chromosome parameters for ADF0 (the result producing branch) of the
 * terrain robot problem.
 *
 * ADF0 has the following Function and Terminal sets.
 *
 * <pre>
 *		Functions = {IFCHARGED, IFSYSUNSAFE, IFOBA, IFDIE, IFAL, IFCSA, IFLGR}
 *		Terminals = {ADF1, Left, Right, Forward, Back}
 * </pre>
 *			
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 */
public class CosSimChromosomeParametersADF0 extends ChromosomeParameters {

	/**
	 * Create the ChromosomeParameters object for ADF0.
	 *
	 * @param robot	The terrainrobot to be controlled.
	 * @param rng	The random number generator to use.
	 * @param arg0	The Terminal representing the argument to ADF2.
	 */
	public CosSimChromosomeParametersADF0(Robot robot, Random rng) {

		maxDepth		= 9;
		maxDepthAtCreation	= 5;
		maxDepthMutation	= 3;

		// the return type for ADF0
		type = CosSimTypes.Vector2Mod10;

		// the table of all types used by this ADF
		types = new Type[1];
		types[0] = CosSimTypes.Vector2Mod10;

		// define the function set
		functions = new Function[7];
		functions[0] = new IFCHARGED(type, robot);
		functions[1] = new IFSYSUNSAFE(type, robot);
		functions[2] = new IFOBA(type, robot);
		functions[3] = new IFDIE(type, robot);
		functions[4] = new IFAL(type, robot);
		functions[5] = new IFCSA(type, robot);
		functions[6] = new IFLGR(type, robot);
		//functions[0] = new ADF2();
		//functions[1] = new IFACS(type, robot);
		//functions[2] = new AddVector2Mod10();
		//functions[3] = new ProgN(type, 2);	// note the type instantiation

		// define the terminal set
		terminals = new Terminal[5];
		terminals[0] = new Left(robot);
		terminals[1] = new Right(robot);
		terminals[2] = new Forward(robot);
		terminals[3] = new Back(robot);
		terminals[4] = new ADF1();
		//terminals[6] = new ConstantVector2Mod10(rng);

		createMethod = CREATE_RAMP_HALF_AND_HALF;
	}
}
