package gpsys.cos;

import gpsys.*;


/**
 * <pre>
 *	Vector2Mod10 IFDIE(Vector2Mod10 displacement)
 * </pre>
 *
 *  The IFDIE Function tells the terrain robot that it is DIEing.
 *
 * @see			gpsys.Type
 * @see			gpsys.Primitive
 * @see			gpsys.Terminal
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 */
public class IFDIE extends Function {
	Robot robot;

	/**
	 * Create a IFDIE object that controls the specified terrain robot.
	 *
	 * @param robot	The Robot to move.
	 */
	public IFDIE(Type returnType, Robot robot) {
		this.robot = robot;
                this.type = returnType;
		this.argTypes = new Type[2];
                this.argTypes[0] = returnType;
                this.argTypes[1] = returnType;

        }

	/**
         * Evaluation of this Function
	 *
	 * @param i			The individual being evaluated.
	 * @param arguments	The Gene tree representing the displacement.
	 *
	 * @return	An Object (actually a Vector2Mod10) representing the
	 * 			displacement.
	 * @exception	EvaluationException	If there is an evaluation failure.
	 */
	public final Object evaluateObject(Individual i, Gene[] arguments)
	throws EvaluationException {
		if (robot.ifdie()==true) 
                	return arguments[0].evaluateObject(i);
		else
                	return arguments[1].evaluateObject(i);

	}

	/**
	 * Creates a new instance of this Object.
	 *
	 * @return	A reference to this same Object since none of the instance
	 *			variables are to be changed.
	 */
	public final Primitive instance() {
		return this;
	}

	/**
	 * Returns a String representation of this Function.
	 *
	 * @return A String containing the name of the Function.
	 */
	public String toString() {
		return "IFDIE";
	}
}
